Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1130)

Unified Diff: src/stub-cache.cc

Issue 408183003: Express LoadIC extra ic state with LoadIC::State (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Ports. Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/stub-cache.h ('k') | src/x64/codegen-x64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/stub-cache.cc
diff --git a/src/stub-cache.cc b/src/stub-cache.cc
index 91cb3870df97e330b9c960655458fd06fd732c90..06c160485342945260c741abba5df1f8c661b9f5 100644
--- a/src/stub-cache.cc
+++ b/src/stub-cache.cc
@@ -559,11 +559,11 @@ RUNTIME_FUNCTION(LoadPropertyWithInterceptorOnly) {
static Object* ThrowReferenceError(Isolate* isolate, Name* name) {
// If the load is non-contextual, just return the undefined result.
// Note that both keyed and non-keyed loads may end up here.
HandleScope scope(isolate);
LoadIC ic(IC::NO_EXTRA_FRAME, isolate);
- if (ic.contextual_mode() != CONTEXTUAL) {
+ if (ic.typeof_state() == INSIDE_TYPEOF) {
return isolate->heap()->undefined_value();
}
« no previous file with comments | « src/stub-cache.h ('k') | src/x64/codegen-x64.h » ('j') | no next file with comments »
@@ -559,11 +559,11 @@ RUNTIME_FUNCTION(LoadPropertyWithInterceptorOnly) {
static Object* ThrowReferenceError(Isolate* isolate, Name* name) {
- // If the load is non-contextual, just return the undefined result.
+ // If the load is inside typeof, just return the undefined result.
// Note that both keyed and non-keyed loads may end up here.
HandleScope scope(isolate);

Powered by Google App Engine
This is Rietveld 408576698